# hdpl-conventions/prototype/hdpl/libhxl/README.md
> Note: as 2021-04-17, the HXL Standard does not have a port to Racket. This
  folder will contain internal functions used on
  `hdpl-conventions/prototype/hdpl/` that MAY (this is not granted) be used
  as base for any future work.

## References

- The standard:
  - https://hxlstandard.org/
- Implementations
  - Python
    - https://github.com/HXLStandard/libhxl-python
  - JavaScript
    - https://github.com/HXLStandard/libhxl-js
